@@ -23,8 +23,7 @@ class HuaweiClient(object):
         return GlobalCredentials(self.ak, self.sk)
 
     def generate_global_client(self, client_name, region_name):
-        region = self.region if self.region else 'cn-east-2'
         return client_name.new_builder(). \
             with_credentials(self.global_credentials). \
-            with_region(region_name.value_of(region)). \
+            with_region(region_name.value_of(self.region)). \
             build()
